==> mgb-0.5.4.1-de.zip: install/update.php <==
<?php
// DO NOT REMOVE THIS COPYRIGHT //
//
// MGB v.null.fuenf (0.5.4.1) (C) by Jrgen Grneisl
// Visit me on http://www.tv-kritik.net/mgb/index.php
//
// This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

         include "../config.php";
         include "../language/lang_update.php";

         if($_GET[action]=="update")
         	{
         	if($_POST[sent]!=1)
         		{
                 	$ausgabe="<br><br><font class='normal'>".$lang['instructions']."</font><br><br>";
                		$ausgabe.="<form method='post' action='".$PHP_SELF."?action=update'>";
			$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
         		$ausgabe.="<br>\n";
         		$ausgabe.="<br>\n";
                 	$ausgabe.="<font class='normal'>".$lang['tables'].":<br><br>".$db[entrys]."<br>".$db[settings]."</font><br><br><br>";
         		$ausgabe.="<input type='submit' value='".$lang['button_value']."'>\n";
         		$ausgabe.="</form>\n";
			$ausgabe.="</center>\n";
                 	}
         	if($_POST[sent]==1)
         		{
                         $eintrag[1]="ALTER TABLE `".$db[settings]."` ADD `moderated` TINYINT( 1 ) NOT NULL DEFAULT '1' AFTER `keywords` ;";
         		$eintrag[2]="ALTER TABLE `".$db[settings]."` DROP `quakemessage` ;";
         		$eintrag[3]="ALTER TABLE `".$db[settings]."` ADD `bbcodes` TINYINT( 1 ) NOT NULL AFTER `smilies` ;";
                         $eintrag[4]="ALTER TABLE `".$db[entrys]."` CHANGE `checked` `checked` TINYINT( 2 ) NULL DEFAULT '' ;";

                         for($i=1;$i<=4;$i++)
				{
                         	$sql=$eintrag[$i];
				$link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
				mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
				$result=mysql_query($sql, $link) or die ("MySQL Fehler");
                                 }

                                 $ausgabe="<br><br><font class='normal'>".$lang['success']."<br><br><a href='../guestbook.php'>".$lang['to_gb']."</a><br><a href='../passwort.php'>".$lang['to_admin']."</a><br><br><br>".$lang['hf']."&nbsp;<a href='http://www.mopzz.de'>mopzz.de</a></font></center>";
                         }
                 }
         else
         	{
                 $ausgabe="<br><br><font class='normal'>".$lang['license']."</font><br><br>";
                 $ausgabe.="<iframe src='../onlinehilfe/gnugpl.html' style='border:2px solid #000000;height:400px;width:500px'><a href='../onlinehilfe/gnugpl.html' target='_blank'>GNU GPL</a></iframe>";
                 $ausgabe.="<br><br>";
                 $ausgabe.="<form method='post' action='".$PHP_SELF."?action=update'>";
                 $ausgabe.="<input type='submit' value='OK'>\n";
                 $ausgabe.="</form>\n";
         	$ausgabe.="</center>\n";
                 }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title><?php echo $lang['title']; ?></title>
<meta name="author" content="mopzz">
<meta name="generator" content="by Hand with Phase 5">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="description" content="MGB 0.5.4  Copyright 2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<style type="text/css">
<!--
	a:link{color:#ffffff;}
         a:active{color:#ffffff;}
         a:visited{color:#ffffff;}
         a:hover{color:#FFDF00;}

         font.normal
         	{
                 font-family:verdana,arial,helvetica,sans-serif;
                 color:#ffffff;
                 font-size:12px;
                 }
         font.fehler
         	{
                 font-family:verdana,arial,helvetica,sans-serif;
                 color:#DF0000;
                 font-size:12px;
                 }
         font.ganzunten
		{
                 font-size:10px;
                 color:#ffffff;
                 font-family:verdana,arial,helvetica,sans-serif;
        		}
         font.copyright
		{
        		font-size:10px;
        		color:#FFFFFF;
        		font-family:verdana;
        		}
         input
         	{
                 border:2px solid #9F9F9F;
                 background-color:#6F6F6F;
                 color:#FFFFFF;
                 }
         body
         	{
                 background-color:#9F9F9F;
                 }
// -->
</style>
</head>
<body>
<center>
<div style="border:2px solid #000000;background-color:#ffffff;padding:10px;width:500px">
<span style="color:#000000;font-size:16px;padding:3px;font-family:verdana,arial,helvetica,sans-serif;font-weight:bold"><?php echo $lang['title']; ?></span>
</div>
<br>
<center>
<br>
<font class='normal'><?php echo $lang['greetz']; ?></font>
<?php
         echo $ausgabe;
?>
<br>
<br>
<?php include "../copyright.php"; ?>
</center>
</body>
</html>

==> mgb-0.5.4.2-de.zip: install/update.php <==
<?php
	/*
	MGB 0.5.4.2
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include "../config.php";
         include "../language/lang_update.php";

         if($_GET[action]=="update")
         	{
         	if($_POST[sent]!=1)
         		{
                 	$ausgabe="<br><br><font class='normal'>".$lang['instructions']."</font><br><br>";
                		$ausgabe.="<form method='post' action='".$PHP_SELF."?action=update'>";
			$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
         		$ausgabe.="<br>\n";
         		$ausgabe.="<br>\n";
                 	$ausgabe.="<font class='normal'>".$lang['tables'].":<br><br>".$db[entrys]."<br>".$db[settings]."</font><br><br><br>";
         		$ausgabe.="<input type='submit' value='".$lang['button_value']."'>\n";
         		$ausgabe.="</form>\n";
			$ausgabe.="</center>\n";
                 	}
         	if($_POST[sent]==1)
         		{
                         $eintrag[1]="ALTER TABLE `".$db[settings]."` ADD `moderated` TINYINT( 1 ) NOT NULL DEFAULT '1' AFTER `keywords` ;";
         		$eintrag[2]="ALTER TABLE `".$db[settings]."` DROP `quakemessage` ;";
         		$eintrag[3]="ALTER TABLE `".$db[settings]."` ADD `bbcodes` TINYINT( 1 ) NOT NULL AFTER `smilies` ;";
                         $eintrag[4]="ALTER TABLE `".$db[entrys]."` CHANGE `checked` `checked` TINYINT( 2 ) NULL DEFAULT '' ;";

                         for($i=1;$i<=4;$i++)
				{
                         	$sql=$eintrag[$i];
				$link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
				mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
				$result=mysql_query($sql, $link) or die ("MySQL Fehler");
                                 }

                                 $ausgabe="<br><br><font class='normal'>".$lang['success']."<br><br><a href='../guestbook.php'>".$lang['to_gb']."</a><br><a href='../passwort.php'>".$lang['to_admin']."</a><br><br><br>".$lang['hf']."&nbsp;<a href='http://www.mopzz.de'>mopzz.de</a></font></center>";
                         }
                 }
         else
         	{
                 $ausgabe="<br><br><font class='normal'>".$lang['license']."</font><br><br>";
                 $ausgabe.="<iframe src='../onlinehilfe/gnugpl.html' style='border:2px solid #000000;height:400px;width:500px'><a href='../onlinehilfe/gnugpl.html' target='_blank'>GNU GPL</a></iframe>";
                 $ausgabe.="<br><br>";
                 $ausgabe.="<form method='post' action='".$PHP_SELF."?action=update'>";
                 $ausgabe.="<input type='submit' value='OK'>\n";
                 $ausgabe.="</form>\n";
         	$ausgabe.="</center>\n";
                 }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title><?php echo $lang['title']; ?></title>
<meta name="author" content="mopzz">
<meta name="generator" content="by Hand with Phase 5">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="description" content="MGB 0.5.4.2  Copyright 2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<style type="text/css">
<!--
	a:link{color:#ffffff;}
         a:active{color:#ffffff;}
         a:visited{color:#ffffff;}
         a:hover{color:#FFDF00;}

         font.normal
         	{
                 font-family:verdana,arial,helvetica,sans-serif;
                 color:#ffffff;
                 font-size:12px;
                 }
         font.fehler
         	{
                 font-family:verdana,arial,helvetica,sans-serif;
                 color:#DF0000;
                 font-size:12px;
                 }
         font.ganzunten
		{
                 font-size:10px;
                 color:#ffffff;
                 font-family:verdana,arial,helvetica,sans-serif;
        		}
         font.copyright
		{
        		font-size:10px;
        		color:#FFFFFF;
        		font-family:verdana;
        		}
         input
         	{
                 border:2px solid #9F9F9F;
                 background-color:#6F6F6F;
                 color:#FFFFFF;
                 }
         body
         	{
                 background-color:#9F9F9F;
                 }
// -->
</style>
</head>
<body>
<center>
<div style="border:2px solid #000000;background-color:#ffffff;padding:10px;width:500px">
<span style="color:#000000;font-size:16px;padding:3px;font-family:verdana,arial,helvetica,sans-serif;font-weight:bold"><?php echo $lang['title']; ?></span>
</div>
<br>
<center>
<br>
<font class='normal'><?php echo $lang['greetz']; ?></font>
<?php
         echo $ausgabe;
?>
<br>
<br>
<?php include "../copyright.php"; ?>
</center>
</body>
</html>
